Searched refs:__handle (Results 1 – 8 of 8) sorted by relevance
| /freebsd-13-stable/contrib/llvm-project/libcxx/include/__format/ |
| HD | format_arg.h | 75 __handle enumerator 142 case __format::__arg_t::__handle: in decltype() 193 case __format::__arg_t::__handle: in __visit_format_arg() 213 struct __handle { struct 215 _LIBCPP_HIDE_FROM_ABI explicit __handle(_Tp& __v) noexcept in __handle() argument 249 __handle __handle_; argument 274 …_LIBCPP_HIDE_FROM_ABI __basic_format_arg_value(__handle&& __value) noexcept : __handle_(std::move(… in __basic_format_arg_value() 295 typename __basic_format_arg_value<_Context>::__handle __h{__arg.__value_.__i128_}; in decltype() 300 typename __basic_format_arg_value<_Context>::__handle __h{__arg.__value_.__u128_}; in decltype() 316 typename __basic_format_arg_value<_Context>::__handle __h{__arg.__value_.__i128_}; in visit() [all …]
|
| HD | format_functions.h | 136 _LIBCPP_HIDE_FROM_ABI constexpr const __compile_time_handle<_CharT>& __handle(size_t __id) const { in __handle() function 238 case __arg_t::__handle: in __compile_time_visit_format_arg() 271 else if (__type == __arg_t::__handle) in __handle_replacement_field() 272 __ctx.__handle(__r.__value).__parse(__parse_ctx); in __handle_replacement_field() 389 __format::__compile_time_handle<_CharT> __handle; member 390 if (__format::__determine_arg_t<_Context, _Tp>() == __format::__arg_t::__handle) 391 __handle.template __enable<_Tp>(); 393 return __handle;
|
| HD | format_arg_store.h | 148 return __arg_t::__handle; in __determine_arg_t() 201 else if constexpr (__arg == __arg_t::__handle) in __create_format_arg() 202 …return basic_format_arg<_Context>{__arg, typename __basic_format_arg_value<_Context>::__handle{__v… in __create_format_arg()
|
| /freebsd-13-stable/contrib/llvm-project/libcxx/src/ |
| HD | fstream.cpp | 29 intptr_t __handle = _get_osfhandle(fileno(__file)); in __filebuf_windows_native_handle() local 30 if (__handle == -1) in __filebuf_windows_native_handle() 32 return reinterpret_cast<void*>(__handle); in __filebuf_windows_native_handle()
|
| HD | print.cpp | 37 intptr_t __handle = _get_osfhandle(fileno(__stream)); in __is_windows_terminal() local 38 if (__handle == -1) in __is_windows_terminal() 42 return GetConsoleMode(reinterpret_cast<void*>(__handle), &__mode); in __is_windows_terminal()
|
| /freebsd-13-stable/contrib/llvm-project/clang/lib/Headers/ |
| HD | __clang_cuda_texture_intrinsics.h | 662 __device__ static void __tex_fetch(__T *__ptr, cudaTextureObject_t __handle, 666 __tex_fetch_v4<__op>::template __run<__FetchT>(__handle, __args...)); 675 __device__ cudaTextureObject_t __tex_handle_to_obj(__T __handle) { 677 asm("mov.b64 %0, %1; " : "=l"(__obj) : "l"(__handle)); 684 __device__ static void __tex_fetch(__T *__ptr, __HandleT __handle, 689 __tex_handle_to_obj(__handle), __args...)); 697 texture<__DataT, __TexT, cudaReadModeNormalizedFloat> __handle, 702 __tex_handle_to_obj(__handle), __args...)); 710 texture<__DataT, __TexT, cudaReadModeElementType> __handle, 715 __tex_handle_to_obj(__handle), __args...));
|
| /freebsd-13-stable/contrib/llvm-project/libcxx/include/ |
| HD | any | 318 …__handle(_Action __act, any const* __this, any* __other, type_info const* __info, const void* __fa… 344 __dest.__h_ = &_SmallHandler::__handle; 385 …__handle(_Action __act, any const* __this, any* __other, type_info const* __info, void const* __fa… 414 __dest.__h_ = &_LargeHandler::__handle; 435 __dest.__h_ = &_LargeHandler::__handle;
|
| /freebsd-13-stable/sys/contrib/dev/rtw89/ |
| HD | rtw8852a.c | 1905 #define __handle(_case) \ in rtw8852a_btc_set_wl_txpwr_ctrl() macro 1924 __handle(all_time); in rtw8852a_btc_set_wl_txpwr_ctrl() 1925 __handle(gnt_bt); in rtw8852a_btc_set_wl_txpwr_ctrl() 1927 #undef __handle in rtw8852a_btc_set_wl_txpwr_ctrl()
|